<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="128"/>
        <source>MX Package Installer</source>
        <translation>MX Pakket Installeerder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Populaire Toepassingen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Category</source>
        <translation>Categorie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Package</source>
        <translation>Pakket</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Info</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="420"/>
        <location filename="../mainwindow.ui" line="817"/>
        <location filename="../mainwindow.ui" line="1074"/>
        <source>Description</source>
        <translation>Beschrijving</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Beheer populaire pakketten&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <location filename="../mainwindow.ui" line="190"/>
        <location filename="../mainwindow.ui" line="686"/>
        <location filename="../mainwindow.ui" line="1099"/>
        <location filename="../mainwindow.ui" line="1321"/>
        <source>search</source>
        <translation>zoeken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.ui" line="699"/>
        <location filename="../mainwindow.ui" line="1167"/>
        <location filename="../mainwindow.ui" line="1293"/>
        <source>= Installed packages</source>
        <translation>= Geïnstalleerde pakketten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Enabled Repos</source>
        <translation>Ingeschakelde Pakketbronnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remove all the packages that are marked as &amp;quot;autoremovable&amp;quot;. If you want to manage them, select Autoremovable from drop-down selection box.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Verwijder alle pakketten die zijn gemarkeerd als &amp;quot;autoverwijderbaar&amp;quot;. Als je ze wilt beheren, selecteer dan Autoverwijderbaar in de vervolgkeuzelijst.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>Autoremove packages</source>
        <translation>Autoverwijder pakketten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <location filename="../mainwindow.ui" line="1384"/>
        <source>Upgrade All</source>
        <translation>Waardeer Alles Op</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <location filename="../mainwindow.ui" line="547"/>
        <location filename="../mainwindow.ui" line="926"/>
        <source>Installed:</source>
        <translation>Geïnstalleerd:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <location filename="../mainwindow.ui" line="540"/>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Total packages:</source>
        <translation>Totaal pakketten:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <location filename="../mainwindow.ui" line="662"/>
        <location filename="../mainwindow.ui" line="987"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation>Installeer ook &quot;Aanbevolen&quot; pakketten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <location filename="../mainwindow.ui" line="577"/>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Upgradable:</source>
        <translation>Opwaardeerbaar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="243"/>
        <location filename="../mainwindow.ui" line="584"/>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Hide library and developer packages</source>
        <translation>Verberg bibliotheek- en ontwikkelaarspakketten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <location filename="../mainwindow.ui" line="633"/>
        <location filename="../mainwindow.ui" line="1006"/>
        <source>Refresh list</source>
        <translation>Ververs lijst</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <location filename="../mainwindow.ui" line="758"/>
        <location filename="../mainwindow.ui" line="1129"/>
        <location filename="../mainwindow.ui" line="1245"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter pakketten op hun status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <location filename="../mainwindow.ui" line="488"/>
        <location filename="../mainwindow.ui" line="761"/>
        <location filename="../mainwindow.ui" line="765"/>
        <location filename="../mainwindow.ui" line="1132"/>
        <location filename="../mainwindow.ui" line="1136"/>
        <location filename="../mainwindow.cpp" line="2827"/>
        <source>All packages</source>
        <translation>Alle pakketten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <location filename="../mainwindow.ui" line="770"/>
        <location filename="../mainwindow.ui" line="1141"/>
        <location filename="../mainwindow.cpp" line="2847"/>
        <source>Installed</source>
        <translation>Geïnstalleerd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <location filename="../mainwindow.ui" line="775"/>
        <location filename="../mainwindow.ui" line="1146"/>
        <location filename="../mainwindow.cpp" line="2848"/>
        <source>Upgradable</source>
        <translation>Opwaardeerbaar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="503"/>
        <location filename="../mainwindow.ui" line="780"/>
        <location filename="../mainwindow.ui" line="1151"/>
        <location filename="../mainwindow.ui" line="1282"/>
        <location filename="../mainwindow.cpp" line="2813"/>
        <location filename="../mainwindow.cpp" line="2849"/>
        <location filename="../mainwindow.cpp" line="2951"/>
        <location filename="../mainwindow.cpp" line="2952"/>
        <source>Not installed</source>
        <translation>Niet geïnstalleerd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <location filename="../mainwindow.ui" line="785"/>
        <location filename="../mainwindow.ui" line="1156"/>
        <location filename="../mainwindow.cpp" line="2363"/>
        <location filename="../mainwindow.cpp" line="2786"/>
        <location filename="../mainwindow.cpp" line="2850"/>
        <location filename="../mainwindow.cpp" line="2936"/>
        <source>Autoremovable</source>
        <translation>Autoverwijderbaar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <location filename="../mainwindow.ui" line="727"/>
        <location filename="../mainwindow.ui" line="855"/>
        <source>= Upgradable package. Newer version available in selected repository.</source>
        <translation>= Opwaardeerbaar pakket. Nieuwere versie beschikbaar in de geselecteerde pakketbron.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <location filename="../mainwindow.ui" line="802"/>
        <location filename="../mainwindow.ui" line="1059"/>
        <source>Package Name</source>
        <translation>Pakket Naam</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1513"/>
        <source>Version</source>
        <translation>Versie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>MX Test Repo</source>
        <translation>MX Test Pakketbron</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <location filename="../mainwindow.ui" line="807"/>
        <location filename="../mainwindow.ui" line="1064"/>
        <source>Repo Version</source>
        <translation>Repoversie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="415"/>
        <location filename="../mainwindow.ui" line="812"/>
        <location filename="../mainwindow.ui" line="1069"/>
        <source>Installed Version</source>
        <translation>Geïnstalleerde versie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="837"/>
        <source>Debian Backports</source>
        <translation>Debian Backports</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1190"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1196"/>
        <location filename="../mainwindow.ui" line="1200"/>
        <location filename="../mainwindow.cpp" line="113"/>
        <location filename="../mainwindow.cpp" line="114"/>
        <source>For all users</source>
        <translation>Voor alle gebruikers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1205"/>
        <source>For current user</source>
        <translation>Voor huidige gebruiker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1213"/>
        <source>Remote (repo):</source>
        <translation>Afstand (pakketbron):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1248"/>
        <location filename="../mainwindow.ui" line="1252"/>
        <location filename="../mainwindow.cpp" line="2795"/>
        <source>All apps</source>
        <translation>Alle apps</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1257"/>
        <location filename="../mainwindow.cpp" line="2801"/>
        <source>All runtimes</source>
        <translation>Alle runtimes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1262"/>
        <location filename="../mainwindow.cpp" line="2807"/>
        <source>All available</source>
        <translation>Alle beschikbare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1267"/>
        <location filename="../mainwindow.cpp" line="2792"/>
        <source>Installed apps</source>
        <translation>Geïnstalleerde apps</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1272"/>
        <location filename="../mainwindow.cpp" line="2789"/>
        <source>Installed runtimes</source>
        <translation>Geïnstalleerde runtimes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1277"/>
        <location filename="../mainwindow.cpp" line="2811"/>
        <location filename="../mainwindow.cpp" line="2944"/>
        <location filename="../mainwindow.cpp" line="2945"/>
        <source>All installed</source>
        <translation>Alles geïnstalleerd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1363"/>
        <source>Total items </source>
        <translation>Totale items</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1377"/>
        <source>Installed apps:</source>
        <translation>Geïnstalleerde apps:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1429"/>
        <source>Advanced</source>
        <translation>Geavanceerd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Total installed size:</source>
        <translation>totaal geïnstalleerd afmeting:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1472"/>
        <source>Remove unused runtimes</source>
        <translation>Ongebruikte looptijden verwijderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1503"/>
        <source>Short Name</source>
        <translation>Korte Naam</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1508"/>
        <source>Full Package Name</source>
        <translation>Volledige Pakket Naam</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1518"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1548"/>
        <location filename="../mainwindow.cpp" line="2505"/>
        <location filename="../mainwindow.cpp" line="2721"/>
        <source>Console Output</source>
        <translation>Console Weergave</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1554"/>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1564"/>
        <source>Respond here, or just press Enter</source>
        <translation>Antwoord hier, of klik op Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1623"/>
        <location filename="../mainwindow.cpp" line="1178"/>
        <location filename="../mainwindow.cpp" line="2837"/>
        <location filename="../mainwindow.cpp" line="2845"/>
        <location filename="../mainwindow.cpp" line="2935"/>
        <location filename="../mainwindow.cpp" line="2941"/>
        <location filename="../mainwindow.cpp" line="3215"/>
        <source>Install</source>
        <translation>Installeer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1629"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1648"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1657"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1689"/>
        <source>About this application</source>
        <translation>Over deze toepassing</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1692"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1698"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1736"/>
        <source>Display help </source>
        <translation>Toon help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1739"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1745"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1761"/>
        <source>Uninstall</source>
        <translation>Deïnstalleer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1767"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Uninstalling packages...</source>
        <translation>Pakketten deïnstalleren...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>Running pre-uninstall operations...</source>
        <translation>Pre-verwijderingsbewerkingen uitvoeren...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="204"/>
        <source>Running post-uninstall operations...</source>
        <translation>Na-deïnstallatie operaties uitvoeren...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="221"/>
        <source>Refreshing sources...</source>
        <translation>Bronnen verversen...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <location filename="../mainwindow.cpp" line="1226"/>
        <location filename="../mainwindow.cpp" line="1360"/>
        <location filename="../mainwindow.cpp" line="1526"/>
        <location filename="../mainwindow.cpp" line="1583"/>
        <location filename="../mainwindow.cpp" line="1881"/>
        <location filename="../mainwindow.cpp" line="2025"/>
        <location filename="../mainwindow.cpp" line="2356"/>
        <location filename="../mainwindow.cpp" line="2375"/>
        <location filename="../mainwindow.cpp" line="2481"/>
        <location filename="../mainwindow.cpp" line="2497"/>
        <location filename="../mainwindow.cpp" line="2589"/>
        <location filename="../mainwindow.cpp" line="2622"/>
        <location filename="../mainwindow.cpp" line="3035"/>
        <location filename="../mainwindow.cpp" line="3111"/>
        <location filename="../mainwindow.cpp" line="3141"/>
        <location filename="../mainwindow.cpp" line="3232"/>
        <location filename="../mainwindow.cpp" line="3253"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="236"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Er was een probleem met het updaten van de bronnen. Sommige bronnen kunnen geen updates aangeleverd hebben. Voor meer info bekijk: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="660"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Please wait...</source>
        <translation>Even wachten aub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1046"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Je staat op het punt de MX Test pakketbron te gebruiken, welke pakketten enkel voor testdoeleinden aangeleverd worden. Het is mogelijk dat je je systeem breekt, dus het is aan te raden dat je een backup maakt van je systeem en installatie of een pakket tegelijk update. Geef alstublieft feedback in het FOrum zodat het pakket geëvalueerd kan worden voor het naar Main verhuist.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1055"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>U gaat de Debian Backports gebruiken welke pakketten bevat vanuit de eerstvolgende Debian uitgave (genaamd &apos;testing&apos;), aangepast en opnieuw gecompileerd voor gebruik op Debian stable. Ze kunnen niet zo uitgebreid getest worden als in de stabiele uitgaven van Debian en MX Linux en worden geleverd op een zoals-is basis, met het risico op incompatibiliteit met andere componenten in Debian stable. Voorzichtigheid is geboden!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1063"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>MX Linux bevat de flatpak pakketbron enkel voor het gemak van de gebruiker, en is niet verantwoordelijk voor het functioneren van de daadwerkelijke individuele flatpaks. Voor meer, raadpleeg flatpaks in de Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1071"/>
        <location filename="../mainwindow.cpp" line="3241"/>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1075"/>
        <source>Do not show this message again</source>
        <translation>Laat dit bericht niet meer zien</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1175"/>
        <source>Remove</source>
        <translation>Verwijder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1191"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>De volgende pakketten zijn geselecteerd. Klik op Details weergeven voor een lijst met wijzigingen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1227"/>
        <location filename="../mainwindow.cpp" line="1361"/>
        <location filename="../mainwindow.cpp" line="1584"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Internet is niet beschikbaar, kan geen pakketlijst downloaden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1230"/>
        <source>Installing packages...</source>
        <translation>Pakketten installeren...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1285"/>
        <source>Post-processing...</source>
        <translation>Installatie nabewerking...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1317"/>
        <source>Pre-processing for </source>
        <translation>Installatie voorbereiding voor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1332"/>
        <source>Installing </source>
        <translation>Installeren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1339"/>
        <source>Post-processing for </source>
        <translation>Installatie nabewerking voor</translation>
    </message>
    <message>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation type="vanished">Er is een fout opgetreden bij het schrijven van bestand: %1. Controleer of u voldoende vrije ruimte op uw schijf heeft</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1527"/>
        <source>There was an error downloading or writing the file: %1. Please check your internet connection and free space on your drive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1592"/>
        <source>Downloading package info...</source>
        <translation>Downloaden pakketten info...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1882"/>
        <source>dpkg-query command returned an error. Please run &apos;dpkg-query -W&apos; in terminal and check the output.</source>
        <translation>Het commando dpkg-query heeft een fout opgeleverd. Voer &apos;dpkg-query -W&apos; uit in terminal en controleer de uitvoer.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2026"/>
        <source>dpkg command returned an error, please run &apos;dpkg --list&apos; in terminal and check the output.</source>
        <translation>Het dpkg commando gaf een foutmelding, voer &apos;dpkg --list&apos; uit in terminal en controleer de uitvoer.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2104"/>
        <location filename="../mainwindow.cpp" line="2191"/>
        <location filename="../mainwindow.cpp" line="2214"/>
        <source>Package info</source>
        <translation>Pakket info</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2121"/>
        <location filename="../mainwindow.cpp" line="3179"/>
        <source>More &amp;info...</source>
        <translation>Meer &amp;informatie...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2152"/>
        <source>Packages to be installed: </source>
        <translation>Pakketten worden geïnstalleerd:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2340"/>
        <location filename="../mainwindow.cpp" line="2352"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <location filename="../mainwindow.cpp" line="2456"/>
        <location filename="../mainwindow.cpp" line="2478"/>
        <location filename="../mainwindow.cpp" line="3032"/>
        <location filename="../mainwindow.cpp" line="3107"/>
        <location filename="../mainwindow.cpp" line="3135"/>
        <location filename="../mainwindow.cpp" line="3228"/>
        <source>Done</source>
        <translation>Klaar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2340"/>
        <location filename="../mainwindow.cpp" line="2352"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <location filename="../mainwindow.cpp" line="2456"/>
        <location filename="../mainwindow.cpp" line="2478"/>
        <location filename="../mainwindow.cpp" line="2494"/>
        <location filename="../mainwindow.cpp" line="3032"/>
        <location filename="../mainwindow.cpp" line="3107"/>
        <location filename="../mainwindow.cpp" line="3135"/>
        <location filename="../mainwindow.cpp" line="3228"/>
        <location filename="../mainwindow.cpp" line="3250"/>
        <source>Processing finished successfully.</source>
        <translation>Proces succesvol beëindigd.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2357"/>
        <location filename="../mainwindow.cpp" line="2376"/>
        <location filename="../mainwindow.cpp" line="3036"/>
        <location filename="../mainwindow.cpp" line="3112"/>
        <location filename="../mainwindow.cpp" line="3142"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Probleem gevonden tijdens installatie, inspecteer aub de console weergave.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2386"/>
        <source>About %1</source>
        <translation>Over %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2387"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2389"/>
        <source>Package Installer for MX Linux</source>
        <translation>Pakket Installeerder voor MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2391"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2392"/>
        <source>%1 License</source>
        <translation>%1 Licentie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2404"/>
        <source>%1 Help</source>
        <translation>%1 Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2481"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>We kwamen een probleem tegen tijdens het deïnstalleren , controleer aub de output</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2494"/>
        <location filename="../mainwindow.cpp" line="3250"/>
        <source>Success</source>
        <translation>Gelukt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2497"/>
        <location filename="../mainwindow.cpp" line="3253"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>We kwamen een probleem tegen tijdens het deïnstalleren van het programma</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2590"/>
        <location filename="../mainwindow.cpp" line="2623"/>
        <source>Could not download the list of packages. Please check your APT sources.</source>
        <translation>Kon de lijst met pakketten niet downloaden. Controleer uw APT bronnen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2662"/>
        <location filename="../mainwindow.cpp" line="2702"/>
        <source>Flatpak not installed</source>
        <translation>Flatpaklniet geïnstalleerd</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2663"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Flatpak is momenteel niet geïnstalleerd.
OK om door te gaan en te installeren?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2702"/>
        <source>Flatpak was not installed</source>
        <translation>Flatpak is niet geïnstalleerd</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2725"/>
        <source>Needs re-login</source>
        <translation>Heeft opnieuw inloggen nodig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2726"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Het kan zijn dat u moet uit- en inloggen om de geïnstalleerde onderdelen in het menu te zien</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2837"/>
        <location filename="../mainwindow.cpp" line="2845"/>
        <location filename="../mainwindow.cpp" line="2937"/>
        <source>Mark keep</source>
        <translation>Markeer behouden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2935"/>
        <source>Upgrade</source>
        <translation>Opwaarderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3064"/>
        <source>Quit?</source>
        <translation>Stoppen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3065"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>Proces loopt nog, stoppen kan het systeem instabiel achter laten.&lt;p&gt;&lt;b&gt;Weet u zeker dat u MX Pakketinstalleerder wilt afsluiten?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3213"/>
        <source>Reinstall</source>
        <translation>Opnieuw installeren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3233"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation>Probleem gedetecteerd tijdens de laatste bewerking, inspecteer de console-uitgang.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3242"/>
        <source>Potentially dangerous operation.
Please make sure you check carefully the list of packages to be removed.</source>
        <translation>Potentieel gevaarlijke operatie.
Zorg ervoor dat u de lijst met te verwijderen pakketten zorgvuldig controleert.</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="16"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Beheer Flatpak Op Afstand</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>Voor alle gebruikers</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation>Voor huidige gebruiker</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>enter Flatpak remote URL</source>
        <translation>Voer Flatpak op afstand URL in</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="38"/>
        <source>enter Flatpakref location to install app</source>
        <translation>Voer Flatpakref locatie in om app te installeren</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="40"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Flatpak op afstanden (pakketbronnen) toevoegen of verwijderen, of installeer apps met flatpakref URL of pad</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Remove remote</source>
        <translation>Verwijder op afstand</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Add remote</source>
        <translation>Voeg op afstand toe</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Install app</source>
        <translation>Installeer app</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="64"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation>Niet verwijderbaar</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="82"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub is de hoofd Flatpak op afstand en zal niet verwijderd worden</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Error adding remote</source>
        <translation>Fout bij toevoegen op afstand</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="102"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Kan de op afstand niet opzetten - commando gaf een fout. Controleer alstublieft het op afstand adres en probeer opnieuw</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Success</source>
        <translation>Gelukt</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Remote added successfully</source>
        <translation>Op afstand succesvol toegevoegd</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="71"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <location filename="../about.cpp" line="82"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="95"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="50"/>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="51"/>
        <source>Dpkg/apt database is locked by another program: %1
Close the program, or wait until it is done processing and try again.</source>
        <translation>Dpkg/apt database is vergrendeld door een ander programma: %1
Sluit het programma of wacht tot het klaar is met verwerken en probeer het opnieuw.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>MX Package Installer is a tool used for managing packages on MX Linux
    - installs popular programs from different sources
    - installs programs from the MX Test repo
    - installs programs from Debian Backports repo
    - installs flatpaks</source>
        <translation>MX Package Installer is een hulpprogramma voor het beheer van pakketten op MX Linux
- installeert populaire programma&apos;s van verschillende bronnen
- installeert programma&apos;s van de MX Test repo
- installeert programma&apos;s van de Debian Backports repo
- installeert flatpaks</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>Skip online check if it falsely reports lack of internet access.</source>
        <translation>Sla de online controle over als deze ten onrechte meldt dat er geen internettoegang is.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <location filename="../main.cpp" line="104"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="97"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>U lijkt ingelogd te zijn als root, gelieve uit te loggen en in te loggen als normale gebruiker om dit programma te gebruiken.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="105"/>
        <source>You must run this program with admin access.</source>
        <translation>Je moet dit programma uitvoeren met admin-toegang.</translation>
    </message>
</context>
</TS>
